# sitechecks

Sitechecks is a set of no-nonsense tests for best practices when it comes
to building and publishing public-facing websites. It does not care about
the latest and greatest technologies. It cares about doing the basics --
making your site usable, discoverable, and shareable.

The issues that sitechecks points out are all actionable and
important enough to actually deal with. We carefully decide what it does
and does not check for in an effort to keep it this way. There are
sometimes rare situations where you will not want to deal with an issue
(usually because you don't have the ability to actually fix it, due to
the way your site is built or how the issue came to be). When that happens,
you have the option to exclude that particular instance from future reports,
so that your open issue list remains actionable. **The goal is to have 0 open issues.**

Things that it checks for:
- Broken links
- Broken images
- Duplicate `id` attributes on the same page
- Delivering images that are far too big (usually by mistake)
- HTTP assets on HTTPS pages (mixed content)
- Not using HTTPS
- Not redirecting HTTP to HTTPS
- Page titles missing
- Page titles that are too long (SEO)
- Page titles that are too short (likely on accident)
- `favicon.ico` in place
- *Soon...*
- Custom string (regular expression) present (Google Analytics, etc.)
- Stray HTML tags
- Meta description tag (SEO, social)
- Open Graph basic tags present
- h1 missing?
- Spaces or other illegal characters in page url
- html lang attribute usage
- Basic spell-check?
- Valid robots.txt

What is it not for?
- Hyper-tuning performance
- Javascript-heavy sites
- Progressive web app tests
- Advanced server configuration issues
