# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sitechecks', 'sitechecks.checks', 'sitechecks.report']

package_data = \
{'': ['*'], 'sitechecks.report': ['templates/*']}

install_requires = \
['beautifulsoup4>=4.9.1,<5.0.0',
 'click>=7.1.2,<8.0.0',
 'jinja2>=2.11.2,<3.0.0',
 'marshmallow>=3.7.1,<4.0.0',
 'pyyaml>=5.3.1,<6.0.0',
 'requests>=2.24.0,<3.0.0']

entry_points = \
{'console_scripts': ['sitechecks = sitechecks.cli:cli']}

setup_kwargs = {
    'name': 'sitechecks',
    'version': '0.1.0',
    'description': 'A no-nonsense set of best-practices for public HTML marketing websites.',
    'long_description': "# sitechecks\n\nSitechecks is a set of no-nonsense tests for best practices when it comes\nto building and publishing public-facing websites. It does not care about\nthe latest and greatest technologies. It cares about doing the basics --\nmaking your site usable, discoverable, and shareable.\n\nThe issues that sitechecks points out are all actionable and\nimportant enough to actually deal with. We carefully decide what it does\nand does not check for in an effort to keep it this way. There are\nsometimes rare situations where you will not want to deal with an issue\n(usually because you don't have the ability to actually fix it, due to\nthe way your site is built or how the issue came to be). When that happens,\nyou have the option to exclude that particular instance from future reports,\nso that your open issue list remains actionable. **The goal is to have 0 open issues.**\n\nThings that it checks for:\n- Broken links\n- Broken images\n- Duplicate `id` attributes on the same page\n- Delivering images that are far too big (usually by mistake)\n- HTTP assets on HTTPS pages (mixed content)\n- Not using HTTPS\n- Not redirecting HTTP to HTTPS\n- Page titles missing\n- Page titles that are too long (SEO)\n- Page titles that are too short (likely on accident)\n- `favicon.ico` in place\n- *Soon...*\n- Custom string (regular expression) present (Google Analytics, etc.)\n- Stray HTML tags\n- Meta description tag (SEO, social)\n- Open Graph basic tags present\n- h1 missing?\n- Spaces or other illegal characters in page url\n- html lang attribute usage\n- Basic spell-check?\n- Valid robots.txt\n\nWhat is it not for?\n- Hyper-tuning performance\n- Javascript-heavy sites\n- Progressive web app tests\n- Advanced server configuration issues\n",
    'author': 'Dropseed',
    'author_email': 'python@dropseed.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://sitechecks.dropseed.io',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
