from bs4 import BeautifulSoup

from .core import Check
from .registry import register
from ..issues import Issues, Issue


@register
class DuplicateIdCheck(Check):
    def run(self):
        issues = Issues()

        ids_seen = {}

        soup = BeautifulSoup(self.content, "html.parser")
        for el in soup.findAll():
            id = el.get("id")
            if not id:
                continue

            if id in ids_seen:
                ids_seen[id].append(el)
            else:
                ids_seen[id] = [el]

        for id, elements in ids_seen.items():
            if len(elements) > 1:
                issues.append(
                    Issue.from_type(
                        type="duplicate-id",
                        url=self.url,
                        extra={"id": id, "elements": [str(x) for x in elements]},
                    )
                )

        return issues
