import requests

# from cachecontrol import CacheControl
# from cachecontrol.cache import DictCache
# from cachecontrol.heuristics import ExpiresAfter


# def print_response(r, *args, **kwargs):
#     log.debug(
#         "response",
#         method=r.request.method,
#         url=r.url,
#         status=r.status_code,
#         from_cache=r.from_cache,s
#     )


# EXPIRATION_DELTA = {"minutes": 7}


# use an in-memory cache, and cache everything no matter what
# this way we can re-get urls across the code without hitting url again
_requests_session = requests.session()
_requests_session.headers.update({"User-Agent": "sitechecks"})
# _requests_session.hooks["response"].append(print_response)

# _cache = DictCache()

# CacheControl(
#     requests_session,
#     heuristic=ExpiresAfter(**EXPIRATION_DELTA),
#     # Don't add GET here -- cache does not distinguish,
#     # and GET isn't used very often in the actual checks
#     cacheable_methods=["HEAD"],
#     cache=cache,
# )


class Fetch:
    def __init__(self):
        self._cache = {}

    def _get_cache(self, url, method):
        cached = self._cache.get(url, {}).get(method.upper(), None)
        if cached:
            print(f"CACHE_HIT {method} {url}")
        return cached

    def _set_cache(self, url, method, response):
        to_set = [url]
        if response.url != url:
            to_set.append(response.url)

        for s in to_set:
            cached_url = self._cache.get(s, {})
            cached_url[method.upper()] = response
            self._cache[s] = cached_url

    def _log_response(self, response):
        print(f"{response.status_code} {response.request.method} {response.url}")

    def head(self, url):
        cached = self._get_cache(url, "HEAD")
        if cached:
            return cached

        response = _requests_session.head(
            url, allow_redirects=True  # not enabled on head by default
        )

        self._log_response(response)
        self._set_cache(url, "HEAD", response)

        return response

    def get(self, url):
        cached = self._get_cache(url, "GET")
        if cached:
            return cached

        response = _requests_session.get(url)

        self._log_response(response)
        self._set_cache(url, "GET", response)

        return response


instance = Fetch()
head = instance.head
get = instance.get
