import os
import datetime

import jinja2


class Report:
    def __init__(self, runner, output_path):
        self.runner = runner
        self.output_path = output_path

        templates_path = os.path.join(os.path.dirname(__file__), "templates")

        self.jinja_environment = jinja2.Environment(
            loader=jinja2.ChoiceLoader([jinja2.FileSystemLoader(templates_path)]),
            autoescape=jinja2.select_autoescape(["html", "xml"]),
            undefined=jinja2.StrictUndefined,  # make sure variables exist
        )

    def generate(self):
        index_template = self.jinja_environment.get_template("index.html")

        now = datetime.datetime.now()
        report_path = os.path.join(
            self.output_path, f"sitechecks-report-{now.isoformat()}.html"
        )

        with open(report_path, "w+") as f:
            f.write(index_template.render({"runner": self.runner, "created_at": now}))

        return report_path
